@@ -1,5 +1,6 @@
 import json
 import time
+from weakref import proxy
 
 import aiohttp
 from aioretry import retry
@@ -9,6 +10,12 @@ from ekp_sdk.util.retry import default_retry_policy
 
 class RestClient:
 
+    def __init__(
+        self,
+        proxy_uri: str
+    ):
+        self.proxy_uri = proxy_uri
+
     @retry(default_retry_policy)
     async def get(
         self,
@@ -16,19 +23,19 @@ class RestClient:
         fn=lambda data, text, response: data,
         limiter: Limiter = None,
         headers=None,
-        allowed_response_codes = [200]
+        allowed_response_codes=[200]
     ):
         if limiter is not None:
             await limiter.acquire()
-        
+
         try:
             async with aiohttp.ClientSession() as session:
                 print(f"🐛 GET {url}")
                 start = time.perf_counter()
                 if headers is None:
-                    response = await session.get(url=url)
+                    response = await session.get(url=url, proxy=self.proxy_uri)
                 else:
-                    response = await session.get(url=url, headers=headers)
+                    response = await session.get(url=url, headers=headers, proxy=self.proxy_uri)
 
                 if (response.status not in allowed_response_codes):
                     raise Exception(f"Response code: {response.status}")
@@ -72,4 +79,4 @@ class RestClient:
                 return fn(data, text, response)
         finally:
             if limiter is not None:
-                limiter.release()
\ No newline at end of file
+                limiter.release()
